Internal functions for working with asset paths.
Summary
Functions
Determine the copy destination path for a given source path.
Copy an asset from its source_path to its dest_path.
Determine the public path for a given source path. This is what will appear
in the output of PhoenixImportmap.importmap().
Functions
Determine the copy destination path for a given source path.
Copy an asset from its source_path to its dest_path.
Determine the public path for a given source path. This is what will appear
in the output of PhoenixImportmap.importmap().