Provides functions for working with importmaps.
Summary
Functions
Copies importmap assets to :copy_destination_path.
Filters an importmap based on a given asset path.
Encodes an importmap into JSON.
Maps local paths from the configured importmap to the location they are being served from.
Types
@type t() :: %PhoenixImportmap.Importmap{imports: map()}
Functions
Copies importmap assets to :copy_destination_path.
Filters an importmap based on a given asset path.
Used to update only assets that have changed in file watching.
Encodes an importmap into JSON.
Maps local paths from the configured importmap to the location they are being served from.
- Strips
:public_asset_path_prefixfrom asset paths so they may be resolved byPlug.Static. - Uses
YourAppWeb.Endpoint.static_path/1to determine whether to use digest URLs.